@@ -16,7 +16,7 @@ options = [
     colors.GREEN + "[h] " + colors.END + "History selection",
     colors.GREEN + "[a] " + colors.END + "Search for Anime",
     colors.GREEN + "[i] " + colors.END + "Print Video Info",
-    colors.GREEN + "[q] " + colors.END + "Quit"
+    colors.GREEN + "[q] " + colors.END + "Quit",
 ]
 
 
@@ -26,9 +26,10 @@ seasonal_options = [
     colors.GREEN + "[l] " + colors.END + "List animes in seasonals file",
     colors.GREEN + "[d] " + colors.END + "Download newest episodes",
     colors.GREEN + "[w] " + colors.END + "Binge watch newest episodes",
-    colors.GREEN + "[q] " + colors.END + "Quit"
+    colors.GREEN + "[q] " + colors.END + "Quit",
 ]
 
+
 @dataclass
 class entry:
     """
@@ -37,6 +38,7 @@ class entry:
     by all classes, it is a essential
     part of this script.
     """
+
     show_name: str = ""
     category_url: str = ""
     ep_url: str = ""
@@ -46,30 +48,35 @@ class entry:
     latest_ep: int = 0
     quality: str = ""
 
+
 def clear_console():
-    os.system('cls' if os.name == 'nt' else 'clear')
+    os.system("cls" if os.name == "nt" else "clear")
+
 
 def error(error: str) -> None:
-    """ 
+    """
     Error function for better error handling,
     that takes an error and prints it to stderr.
     """
-    sys.stderr.write(
-        colors.ERROR + "anipy-cli: error: " + error + colors.END + '\n')
-    
+    sys.stderr.write(colors.ERROR + "anipy-cli: error: " + error + colors.END + "\n")
+
+
 def response_err(req, link) -> None:
-    """ 
+    """
     Function that checks if a requsted
     was succesfull.
     """
     if req.ok:
         pass
     else:
-        error(f"requsted url not avalible/blocked: {link}: response-code: {req.status_code}")
+        error(
+            f"requsted url not avalible/blocked: {link}: response-code: {req.status_code}"
+        )
         sys.exit()
 
+
 def loc_err(soup, link: str, element: str) -> None:
-    """ 
+    """
     Function that checks if beautifulsoup
     could locate a element.
     """
@@ -77,19 +84,21 @@ def loc_err(soup, link: str, element: str) -> None:
         error(f"could not locate {element}: {link}")
         sys.exit()
 
+
 def keyboard_inter() -> None:
     print(colors.ERROR + "\nanipy-cli: error: interrupted")
     sys.exit()
 
+
 def read_json(path):
     """
     Read a json file, if
-    it doesn't exist create it, 
+    it doesn't exist create it,
     along with user_files folder.
     """
     while True:
         try:
-            with open(path, 'r') as data:
+            with open(path, "r") as data:
                 json_data = json.load(data)
             break
 
@@ -98,16 +107,17 @@ def read_json(path):
                 config.user_files_path.mkdir(exist_ok=True)
                 path.touch(exist_ok=True)
                 # avoids error on empty json file
-                with path.open('a') as f:
-                    f.write('{}')
+                with path.open("a") as f:
+                    f.write("{}")
                 continue
-            
+
             except PermissionError:
                 error(f"Unable to create {path} due to permissions.")
                 sys.exit()
-    
+
     return json_data
 
+
 def print_names(names):
     """
     Cli function that takes a
@@ -115,32 +125,34 @@ def print_names(names):
     them to the terminal.
     """
     for number, value in enumerate(names, 1):
-        color = ''
+        color = ""
         if number % 2 == 0:
             color = colors.YELLOW
 
-        print(colors.GREEN 
-              + f"[{number}]" 
-              + colors.END 
-              + f"{color} {value}" 
-              + colors.END)
+        print(
+            colors.GREEN + f"[{number}]" + colors.END + f"{color} {value}" + colors.END
+        )
+
 
 def get_anime_info(category_url: str) -> dict:
     """
     Get metadata about an anime.
     """
     r = requests.get(category_url)
-    soup = BeautifulSoup(r.text, 'html.parser')
-    info_body = soup.find('div', {'class': 'anime_info_body_bg'})
-    image_url = info_body.find('img')['src']
-    other_info = info_body.find_all('p', {'class': 'type'})
+    soup = BeautifulSoup(r.text, "html.parser")
+    info_body = soup.find("div", {"class": "anime_info_body_bg"})
+    image_url = info_body.find("img")["src"]
+    other_info = info_body.find_all("p", {"class": "type"})
     info_dict = {
-        'image_url': image_url,
-        'type': other_info[0].text.replace("\n", "").replace("Type: ", ""),
-        'synopsis': other_info[1].text.replace("\n", ""),
-        'genres': [x['title'] for x in BeautifulSoup(str(other_info[2]), 'html.parser').find_all('a')],
-        'release_year':other_info[3].text.replace("Released: ", ""),
-        'status': other_info[4].text.replace("\n", "").replace("Status: ", ""),
+        "image_url": image_url,
+        "type": other_info[0].text.replace("\n", "").replace("Type: ", ""),
+        "synopsis": other_info[1].text.replace("\n", ""),
+        "genres": [
+            x["title"]
+            for x in BeautifulSoup(str(other_info[2]), "html.parser").find_all("a")
+        ],
+        "release_year": other_info[3].text.replace("Released: ", ""),
+        "status": other_info[4].text.replace("\n", "").replace("Status: ", ""),
     }
 
     return info_dict
